@@ -48,4 +48,4 @@ class Command(BaseCommand):
                 'Error trying to create EnterpriseUser with uuid '
                 '{}: {}'.format(enterprise_id, exc)
             )
-            raise CommandError(info)
+            raise CommandError(info) from exc
