@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Classes that handle sending reports for EnterpriseCustomers.
 """
@@ -9,7 +8,6 @@ import datetime
 import json
 import logging
 from collections import OrderedDict
-from io import open  # pylint: disable=redefined-builtin
 from uuid import UUID
 
 from enterprise_reporting.clients.enterprise import (
@@ -17,6 +15,7 @@ from enterprise_reporting.clients.enterprise import (
     EnterpriseAPIClient,
     EnterpriseDataApiClient
 )
+from enterprise_reporting.clients.s3 import S3Client
 from enterprise_reporting.clients.vertica import VerticaClient
 from enterprise_reporting.delivery_method import SFTPDeliveryMethod, SMTPDeliveryMethod
 from enterprise_reporting.utils import decrypt_string, generate_data
@@ -25,7 +24,7 @@ LOGGER = logging.getLogger(__name__)
 NOW = datetime.datetime.now().strftime("%Y-%m-%d")
 
 
-class EnterpriseReportSender(object):
+class EnterpriseReportSender:
     """
     Class that handles the process of sending a data report to an Enterprise Customer.
     """
@@ -93,14 +92,14 @@ class EnterpriseReportSender(object):
                 decrypt_string(reporting_config['encrypted_sftp_password']),
             )
         else:
-            raise ValueError('Invalid delivery method: {}'.format(delivery_method_str))
+            raise ValueError(f'Invalid delivery method: {delivery_method_str}')
 
         return EnterpriseReportSender(reporting_config, delivery_method)
 
     @property
     def data_report_file_name(self):
         """Get the full path to the report file."""
-        date_str = "_{}".format(NOW) if self.reporting_config.get('include_date') else ""
+        date_str = f"_{NOW}" if self.reporting_config.get('include_date') else ""
         return "{dir}/{enterprise_id}_{data}_{ext}{date_str}.{ext}".format(
             dir=self.FILE_WRITE_DIRECTORY,
             enterprise_id=self.enterprise_customer_uuid,
@@ -116,7 +115,7 @@ class EnterpriseReportSender(object):
 
     def send_enterprise_report(self):
         """Generate the report file of the appropriate type and send it through the configured delivery method."""
-        LOGGER.info('Starting process to send report to {}'.format(self.enterprise_customer_name))
+        LOGGER.info(f'Starting process to send report to {self.enterprise_customer_name}')
         files = self._generate_enterprise_report()
         if files:
             self.delivery_method.send(files)
@@ -129,7 +128,7 @@ class EnterpriseReportSender(object):
 
     def _generate_enterprise_report(self):
         """Calls the appropriate method for generating the report, e.g. the method for a CSV report of Catalog data."""
-        LOGGER.info('Generating {} report in {} format...'.format(self.data_type, self.report_type))
+        LOGGER.info(f'Generating {self.data_type} report in {self.report_type} format...')
         return getattr(self, '_generate_enterprise_report_{type}_{ext}'.format(
             type=self.data_type,
             ext=self.report_type
@@ -146,11 +145,47 @@ class EnterpriseReportSender(object):
                 fields=','.join(self.VERTICA_QUERY_FIELDS),
                 enterprise_id=UUID(self.enterprise_customer_uuid).hex
             )
-            LOGGER.debug('Executing this Vertica query: {}'.format(query))
+            LOGGER.debug(f'Executing this Vertica query: {query}')
             data_report_file_writer.writerows(vertica_client.stream_results(query))
         vertica_client.close_connection()
         return [data_report_file]
 
+    def _generate_enterprise_report_grade_csv(self):
+        """Query S3 and write output to csv file."""
+        s3_client = S3Client()
+        with open(self.data_report_file_name, 'wb') as data_report_file:
+            LOGGER.debug('Fetching enterprise grade report from S3')
+            # temporarily adding file path for PEARSON
+            s3_client.get_enterprise_report(
+                'PEARSON/ENT_REPORT_PEARSON_PERSISTENTSUBSECTIONGRADE/ENT_REPORT_PEARSON_PERSISTENTSUBSECTIONGRADE.csv',
+                data_report_file
+            )
+        return [data_report_file]
+
+    def _generate_enterprise_report_course_structure_csv(self):
+        """Query S3 and write output to csv file."""
+        s3_client = S3Client()
+        with open(self.data_report_file_name, 'wb') as data_report_file:
+            LOGGER.debug('Fetching enterprise course structure report from S3')
+            # temporarily adding file path for PEARSON
+            s3_client.get_enterprise_report(
+                'PEARSON/ENT_REPORT_PEARSON_COURSE_METRICS/ENT_REPORT_PEARSON_COURSE_METRICS.csv',
+                data_report_file
+            )
+        return [data_report_file]
+
+    def _generate_enterprise_report_completion_csv(self):
+        """Query S3 and write output to csv file."""
+        s3_client = S3Client()
+        with open(self.data_report_file_name, 'wb') as data_report_file:
+            LOGGER.debug('Fetching enterprise completion report from S3')
+            # temporarily adding file path for PEARSON
+            s3_client.get_enterprise_report(
+                'PEARSON/ENT_REPORT_PEARSON_BLOCK_COMPLETION/ENT_REPORT_PEARSON_BLOCK_COMPLETION.csv',
+                data_report_file
+            )
+        return [data_report_file]
+
     def _generate_enterprise_report_progress_v2_csv(self):
         """Query the Enterprise Data API to get progress data to be turned into a CSV."""
         enrollments = EnterpriseDataApiClient().get_enterprise_enrollments(self.enterprise_customer_uuid)['results']
@@ -234,5 +269,5 @@ class EnterpriseReportSender(object):
             self.enterprise_customer_uuid,
             self.reporting_config,
         )
-        LOGGER.debug('Gathered this content metadata: {}'.format(content_metadata))
+        LOGGER.debug(f'Gathered this content metadata: {content_metadata}')
         return content_metadata
